@@ -17,7 +17,6 @@ use base 'HTML::Tested';
 
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
-use HTML::Tested qw(HTV HT);
 
 sub ht_root_class { return __PACKAGE__ . '::Root'; }
 
@@ -25,18 +24,18 @@ sub on_inheritance_end {
 	my $class = shift;
 	my $rc = $class->ht_root_class;
 	my $rci = $rc . '::Item';
-	$rci->ht_add_widget(HTV."::Link", '[% col1_v %]'
+	$rci->ht_add_widget(::HTV."::Link", '[% col1_v %]'
 		, href_format => '../info/r?edit_link=%s'
 		, cdbi_bind => [ [% col1_v %] => 'Primary' ]
 		, column_title => '[% link_title_v %]');
-[% FOREACH list_fields_v %]$rci->ht_add_widget(HTV."::Marked", '[% field %]'
+[% FOREACH list_fields_v %]$rci->ht_add_widget(::HTV."::Marked", '[% field %]'
 		, cdbi_bind => '', column_title => '[% title %]');
 [% END %]
 	$rci->bind_to_class_dbi($class->main_subsystem_class
 			->[% db_class_v %]);
 
-	$rc->ht_add_widget(HTV."::Form", 'form', default_value => 'u');
-	$rc->ht_add_widget(HT."::List", '[% list_name_v %]', $rc . '::Item'
+	$rc->ht_add_widget(::HTV."::Form", 'form', default_value => 'u');
+	$rc->ht_add_widget(::HT."::List", '[% list_name_v %]', $rc . '::Item'
 		, render_table => 1);
 }
 
